@@ -23,7 +23,6 @@ from heat.common.i18n import _
 from heat.engine import attributes
 from heat.engine.clients import progress
 from heat.engine import constraints
-from heat.engine import function
 from heat.engine import properties
 from heat.engine.resources.openstack.neutron import port as neutron_port
 from heat.engine.resources.openstack.neutron import subnet
@@ -1204,6 +1203,10 @@ class Server(server_base.BaseServer, sh.SchedulerHintsMixin,
 
         after_props = json_snippet.properties(self.properties_schema,
                                               self.context)
+        if self.METADATA in prop_diff:
+            server = self.client_plugin().get_server(self.resource_id)
+            self.client_plugin().meta_update(server,
+                                             after_props[self.METADATA])
 
         if self.TAGS in prop_diff:
             self._update_server_tags(after_props[self.TAGS] or [])
@@ -1577,7 +1580,8 @@ class Server(server_base.BaseServer, sh.SchedulerHintsMixin,
 
     def handle_restore(self, defn, restore_data):
         image_id = restore_data['resource_data']['snapshot_image_id']
-        props = function.resolve(self.properties.data)
+        props = dict((k, v) for k, v in self.properties.data.items()
+                     if v is not None)
         props[self.IMAGE] = image_id
         return defn.freeze(properties=props)
 
