@@ -102,6 +102,7 @@ class SoftwareConfigService(object):
         rs = db_api.resource_get_by_physical_resource_id(cnxt, server_id)
         if not rs:
             return
+        cnxt.session.refresh(rs)
         deployments = self.metadata_software_deployments(cnxt, server_id)
         md = rs.rsrc_metadata or {}
         md['deployments'] = deployments
@@ -256,7 +257,7 @@ class SoftwareConfigService(object):
             'stack_user_project_id': stack_user_project_id,
             'action': action,
             'status': status,
-            'status_reason': str(status_reason)})
+            'status_reason': six.text_type(status_reason)})
         self._push_metadata_software_deployments(
             cnxt, server_id, stack_user_project_id)
         return api.format_software_deployment(sd)
@@ -337,7 +338,7 @@ class SoftwareConfigService(object):
         if status:
             update_data['status'] = status
         if status_reason:
-            update_data['status_reason'] = str(status_reason)
+            update_data['status_reason'] = six.text_type(status_reason)
         if updated_at:
             update_data['updated_at'] = timeutils.normalize_time(
                 timeutils.parse_isotime(updated_at))
